pub struct AgentTool { /* private fields */ }Expand description
The AgentTool — spawns independent sub-agents.
This must be constructed with a reference to the parent’s provider so sub-agents can make their own API calls.
Implementations
Sourceimpl AgentTool
impl AgentTool
Sourcepub fn new(
provider_factory: impl Fn() -> Box<dyn Provider> + Send + Sync + 'static,
tools: Vec<Box<dyn Tool>>,
) -> Self
pub fn new( provider_factory: impl Fn() -> Box<dyn Provider> + Send + Sync + 'static, tools: Vec<Box<dyn Tool>>, ) -> Self
Create an AgentTool with a provider factory and available tools.
The provider factory creates a new provider instance for each sub-agent.
The available_tools list will have “Agent” filtered out automatically.